#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rank2classes
version:              1.4.1
visibility:           public
id:                   rank2classes-1.4.1-87arDcY6M72Ahu2Kg1agTj
key:                  rank2classes-1.4.1-87arDcY6M72Ahu2Kg1agTj
license:              BSD-3-Clause
copyright:            (c) 2017 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/grampa/tree/master/rank2classes
synopsis:
    standard type constructor class hierarchy, only with methods of rank 2 types

description:
    A mirror image of the standard type constructor class hierarchy rooted in '\''Functor'\'', except with methods of rank 2
    types and class instances of kind @(k->*)->*@. The classes enable generic handling of heterogenously typed data
    structures and other neat tricks.

category:             Control, Data, Generics
abi:                  bb15f38d384327e85f5fc2ee07827554
exposed:              True
exposed-modules:      Rank2 Rank2.TH
import-dirs:          /usr/lib/ghc-8.10.5/site-local/rank2classes-1.4.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/rank2classes-1.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/rank2classes-1.4.1
hs-libraries:         HSrank2classes-1.4.1-87arDcY6M72Ahu2Kg1agTj
depends:
    base-4.14.2.0 distributive-0.6.2.1-FKGYrCjdfe8EPx7TggrhZc
    template-haskell-2.16.0.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-rank2classes/html/rank2classes.haddock

haddock-html:         /usr/share/doc/haskell-rank2classes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

